executing: Get the currently executing AST node of a frame, and other information
=================================================================================

Description
-----------

Get the currently executing AST node of a frame, and other information

License
-------

MIT

Upstream Contact
----------------

https://pypi.org/project/executing/

